@@ -23,6 +23,7 @@
 #include <QDebug>
 #include <QDir>
 #include <QFileInfo>
+#include <QFileDialog>
 #include <QInputDialog>
 #include <QLabel>
 #include <QMenu>
@@ -36,17 +37,16 @@
 
 #include <KActionCollection>
 #include <KConfigGroup>
-#include <KFileDialog>
 #include <KHelpClient>
-#include <KLocale>
+#include <KIO/StatJob>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KRecentFilesAction>
 #include <KSharedConfig>
 #include <KToolBarPopupAction>
 
-#include <kio/netaccess.h>
-#include <knewstuff3/downloaddialog.h>
+#include <kns3/downloaddialog.h>
+#include <QFileDialog>
 
 #include "interpreter/errormsg.h"
 #include "interpreter/translator.h"
@@ -658,7 +658,8 @@ void MainWindow::updateLanguagesMenu()
 	QAction* a;
 	// sort the dictionaries using an algorithm found in the qt docs:
 	QMap<QString, QString> map;
-	foreach (const QString &lang_code, KLocale::global()->languageList())
+	QSet<QString> dictionaries = KLocalizedString::availableApplicationTranslations();
+	foreach (const QString &lang_code, dictionaries)
 		map.insert(codeToFullName(lang_code), lang_code);
 	// populate the menu:
 	foreach (const QString &lang_code, map) {
@@ -833,10 +834,9 @@ bool MainWindow::setCurrentLanguage(const QString &lang_code)  // 2 or 5 digit c
 
 QString MainWindow::codeToFullName(const QString& lang_code)
 {
-	// TODO test this function with more than one language loaded into KDE
 	return QString(lang_code == "en_US" ?
 			i18n("English [built in]") :
-			i18n("%1 (%2)", KLocale::global()->languageCodeToName(lang_code.left(2)), lang_code)
+			i18n("%1 (%2)", QLocale(lang_code.left(2)).nativeLanguageName(), lang_code)
 		);
 }
 
@@ -1025,33 +1025,37 @@ void MainWindow::writeConfig()
 void MainWindow::exportToPng()
 {
 	// copied from edit code for file selection
-	QUrl url = KFileDialog::getSaveUrl(QString(), QString("*.png|%1\n*|%2").arg(i18n("PNG Images")).arg(i18n("All files")), this, i18n("Save as Picture"));
-    if (url.isEmpty())
-        return;
-	if (KIO::NetAccess::exists(url, KIO::NetAccess::SourceSide, this) &&
+	QUrl url = QFileDialog::getSaveFileUrl(this,
+					       i18n("Save as Picture"),
+					       QUrl(),
+					       QString("%1 (*.png);;%2 (*)").arg(i18n("PNG Images")).arg(i18n("All files")));
+	if (url.isEmpty())
+		return;
+	KIO::StatJob *job = KIO::stat(url, KIO::StatJob::SourceSide, 0);
+	if (job->exec() &&
 	    KMessageBox::warningContinueCancel(this,
 			i18n("Are you sure you want to overwrite %1?", url.fileName()),
 			i18n("Overwrite Existing File"),KGuiItem(i18n("&Overwrite")),
-            KStandardGuiItem::cancel(), i18n("&Overwrite")) != KMessageBox::Continue) {
+			KStandardGuiItem::cancel(), i18n("&Overwrite")) != KMessageBox::Continue) {
 		return;
-    }
-    // get our image from the canvas and save to png
-    QImage pict = canvas->getPicture();
-    if (url.isLocalFile()) {
-        pict.save(url.toLocalFile(), "PNG");
-    } else {
-        pict.save(url.path(), "PNG");
-    }
+	}
+	// get our image from the canvas and save to png
+	QImage pict = canvas->getPicture();
+	if (url.isLocalFile()) {
+		pict.save(url.toLocalFile(), "PNG");
+	} else {
+		pict.save(url.path(), "PNG");
+	}
 }
 
 void MainWindow::exportToSvg()
 {
-    // copied from edit code for file selection
-    // canvas->saveAsSvg() does not handle QUrl, so only local files are accepted
-	QString path = KFileDialog::getSaveFileName(QString(), QString("*.svg|%1\n*|%2").arg(i18n("Scalable Vector Graphics")).arg(i18n("All files")), this, i18n("Save as SVG"));
+	// copied from edit code for file selection
+	// canvas->saveAsSvg() does not handle QUrl, so only local files are accepted
+	QString path = QFileDialog::getSaveFileName(this, i18n("Save as SVG"), QString(), QString("%1 (.*svg);;%2 (*)").arg(i18n("Scalable Vector Graphics")).arg(i18n("All files")));
 	if (path.isEmpty())
 		return;
-	if (KIO::NetAccess::exists(path, KIO::NetAccess::SourceSide, this) &&
+	if (QFile::exists(path) &&
 	    KMessageBox::warningContinueCancel(this,
 			i18n("Are you sure you want to overwrite %1?", path),
 			i18n("Overwrite Existing File"),KGuiItem(i18n("&Overwrite")),
@@ -1062,12 +1066,12 @@ void MainWindow::exportToSvg()
 
 void MainWindow::exportToHtml()
 {
-    // copied from edit code for file selection
-    // we do not handle QUrl, so only local files are accepted
-	QString path = KFileDialog::getSaveFileName(QString(), QString("*.html|%1\n*|%2").arg(i18n("HTML documents")).arg(i18n("All files")), this, i18n("Save code as HTML"));
+	// copied from edit code for file selection
+	// we do not handle QUrl, so only local files are accepted
+	QString path = QFileDialog::getSaveFileName(this, i18n("Save code as HTML"), QString(), QString("*.html|%1\n*|%2").arg(i18n("HTML documents")).arg(i18n("All files")));
 	if (path.isEmpty())
 		return;
-	if (KIO::NetAccess::exists(path, KIO::NetAccess::SourceSide, this) &&
+	if (QFile::exists(path) &&
 	    KMessageBox::warningContinueCancel(this,
 			i18n("Are you sure you want to overwrite %1?", path),
 			i18n("Overwrite Existing File"),KGuiItem(i18n("&Overwrite")),
